Module buffer

Module buffer 

The primary Widget of Duat, used to display buffers.

Most extensible features of Duat have the primary purpose of serving the Buffer, such as multiple Cursors, a History system, RawArea::PrintInfo, etc.

The Buffer also provides a list of printed lines through the Handle::printed_lines method. This method is notably used by the LineNumbers widget, that shows the numbers of the currently printed lines.

Structs

Buffer
The widget that is used to print and edit buffers.
BufferId
A unique identifier for a Buffer.
BufferOpts
The default suite of options available to Buffers
BufferParts
This function is like TextParts, but it includes information about Changes that took place since the last call to BufferTracker::parts, as well as all the ranges of the Text that still need updating.
BufferTracker
A tracker to keep up to date on changes to Buffers
Change
A change in a buffer, with a start, taken text, and added text
History
The history of edits, contains all moments.
Moment
A moment in history, which may contain changes, or may just contain selections.
PerBuffer
A struct to associate one T to each Buffer.
RangesToUpdate
A list of Range<usize>s of byte indices in a Buffer that need to be updated

Enums

PathKind
Represents the presence or absence of a path.