pub struct BufferParts<'b> {
pub strs: &'b Strs,
pub tags: Tags<'b>,
pub selections: &'b Selections,
pub changes: Changes<'b>,
pub ranges_to_update: RangesToUpdate<'b>,
pub opts: &'b BufferOpts,
}Expand description
This function is like TextParts, but it includes information
about Changes that took place since the last call to
BufferTracker::parts, as well as all the ranges of the
Text that still need updating.
Fields
strs: &'b Strsselections: &'b SelectionsThe Selections of the Buffer.
changes: Changes<'b>An ExactSizeIterator of all Changes that took place
since the last call to BufferTracker::parts
ranges_to_update: RangesToUpdate<'b>A list of the ranges that need to be updated.
This should be used in conjunction with visible ranges
acquired from a Handle<Buffer>, in order to update only
what is visible on screen.
opts: &'b BufferOptsThe BufferOpts of the Buffer in question.