Moment

Struct Moment 

pub struct Moment { /* private fields */ }
A moment in history, which may contain changes, or may just contain selections.

It also contains information about how to print the buffer, so that going back in time is less jarring.

Implementations

Source

impl Moment

pub fn iter(&self) -> Changes<'_>

An ExactSizeIterator over the Changes in this Moment.

pub fn len(&self) -> usize

Returns the number of Changes in this Moment

pub fn is_empty(&self) -> bool

Wether there are any Changes in this Moment

This can happen when creating a Moment::default.