pub enum Scope {
Local,
Global,
}Expand description
Command Parameter: Global or local scope for commands
This struct captures a Flag if it exists, if it is --global,
then the scope is global. If the flag is something else, it
returns an Err. If there is no Flag then the scope is
Scope::Local.
Variants
Local
The scope of this command is meant to be local
This is a loose definition. Usually, it means it should affect
stuff related only to the current Buffer, but you can
decide that.
Global
The scope of this command is meant to be global
This is a loose definition. Usually, it means it should affect
stuff related to all Buffers, but you decide what it
really means.