edit

Function edit 

pub fn edit(pa: &mut Pass, buffer: impl Display) -> CmdResult
Switches to/opens a Buffer with the given name.

If you wish to specifically switch to buffers that are already open, use buffer.

If there are more arguments, they will be ignored.