pub struct Args<'a> { /* private fields */ }Expand description
The list of arguments passed to a command
Implementations
Sourceimpl<'arg> Args<'arg>
impl<'arg> Args<'arg>
Sourcepub fn next_as<P: Parameter>(&mut self, pa: &Pass) -> Result<P, Text>
pub fn next_as<P: Parameter>(&mut self, pa: &Pass) -> Result<P, Text>
Tries to parse the next argument as P
If parsing fails, Args will be reset as if this function
wasn’t called.
Sourcepub fn next_as_with_form<P: Parameter>(
&mut self,
pa: &Pass,
) -> Result<(P, Option<FormId>), Text>
pub fn next_as_with_form<P: Parameter>( &mut self, pa: &Pass, ) -> Result<(P, Option<FormId>), Text>
Tries to parse the next argument as P, also returning the
Option<Form>
If parsing fails, Args will be reset as if this function
wasn’t called.
Sourcepub fn next_else<T: Into<Text>>(
&mut self,
to_text: T,
) -> Result<&'arg str, Text>
pub fn next_else<T: Into<Text>>( &mut self, to_text: T, ) -> Result<&'arg str, Text>
Tries to get the next argument, otherwise returns a Text
Sourcepub fn next_start(&mut self) -> Option<usize>
pub fn next_start(&mut self) -> Option<usize>
Returns the char position of the next argument
Mostly used for error feedback by the PromptLine
Sourcepub fn param_range(&self) -> Range<usize>
pub fn param_range(&self) -> Range<usize>
The range of the previous Parameter
Mostly used for error feedback by the PromptLine
Sourcepub fn last_parsed(&self) -> Vec<TypeId>
pub fn last_parsed(&self) -> Vec<TypeId>
The last Parameter type that was parsed
This can/should be used for argument completion.
Sourcepub fn use_completions_for<P: Parameter>(&mut self)
pub fn use_completions_for<P: Parameter>(&mut self)
Declare that you are trying to parse the given Parameter
type
This is used on completions, where multiple pools of choices may be selected from in order to get the completions list to show.