CmdBuilder

Struct CmdBuilder 

pub struct CmdBuilder { /* private fields */ }
A builder for a command

This struct is created by cmd::add, and when it is dropped, the command gets added.

Implementations

Source

impl CmdBuilder

pub fn doc(self, short: Text, long: Option<Text>) -> Self

Adds documentation to this command

pub fn doc_param( self, short: Text, long: Option<Text>, name: Option<Text>, ) -> Self

Adds documentation for the next Parameter of the command

You have to give a short description, and you may give a long description and a name.

The short and long descriptions should not present the same information, the long description merely adds additional context.

The name argument will rename the argument to something else. If it is excluded, then the default name (provided by Parameter::arg_name will be used.