pub struct ParamDoc {
pub arg_name: Text,
pub short: Option<Text>,
pub long: Option<Text>,
}Expand description
The description for a Parameter, which is used by Duat’s
commands
Fields
arg_name: TextThe name for the parameter
This will be used when formatting documentation for the
command, like <path> in buffer <path>.
short: Option<Text>“Short” documentation for the Parameter
This should be a short line of few words, meant for possibly being displayed in a list.
Note that this is not a short version of
ParamDoc::long. So they shouldn’t present the same
information.
long: Option<Text>“Long” documentation for a command
This should add more details to the Text of
ParamDoc::short. This description is meant to be shown
when more information is required on top of
ParamDoc::short, so they shouldn’t present duplicate
information.