current_buffer

Function current_buffer 

pub fn current_buffer(pa: &Pass) -> Handle
Returns a “fixed” Handle for the currently active Buffer.

This Handle will always point to the same Buffer, even when it is not active. If you want a Handle that always points to the current Buffer, see dynamic_buffer.