DynBuffer

Struct DynBuffer 

pub struct DynBuffer { /* private fields */ }
A “dynamic” Handle wrapper for Buffers.

This Handle wrapper will always point to the presently active Buffer. It can also detect when that Buffer has been changed or when another Buffer becomes the active Buffer.

Implementations

Source

impl DynBuffer

pub fn has_changed(&self, pa: &Pass) -> bool

Wether the Buffer pointed to has changed or swapped with another.

pub fn swap_to_current(&mut self)

Swaps the DynBuffer to the currently active Buffer.

pub fn read<'a>(&'a mut self, pa: &'a Pass) -> &'a Buffer

Reads the presently active Buffer.

pub fn handle(&self) -> &Handle

The Handle<Buffer> currently being pointed to.

pub fn declare_as_read(&self)

Simulates a read without actually reading.

This is useful if you want to tell Duat that you don’t want has_changed to return true, but you don’t have a Pass available to read the value.

This assumes that you don’t care about the active Buffer possibly being swapped.

pub fn write<'a>(&'a self, pa: &'a mut Pass) -> &'a mut Buffer

Reads the presently active Buffer.

pub fn write_with_area<'a>( &'a self, pa: &'a mut Pass, ) -> (&'a mut Buffer, &'a mut Area)

Writes to the Buffer and Area, making use of a Pass.

pub fn declare_written(&self)

Simulates a write without actually writing.

This is useful if you want to tell Duat that you want has_changed to return true, but you don’t have a Pass available to write the value with.