pub struct Location { /* private fields */ }Expand description
The location where a log came from
Implementations
Sourceimpl Location
impl Location
Sourcepub fn new(filename: impl ToString, line: u32, col: u32) -> Self
pub fn new(filename: impl ToString, line: u32, col: u32) -> Self
Returns a new custom Location.
You can use this to add a more nuanced location for an error, instead of just letting duat pick one automatically.
An example of this is with treesitter query errors, where
std::panic::Location::caller would return an error within
a rust file, but a more appropriate position would be on the
actual query file.
Sourcepub fn from_panic_location(loc: &Location<'_>) -> Self
pub fn from_panic_location(loc: &Location<'_>) -> Self
Returns a new Location from a regular panic Location