DataMap

Struct DataMap 

pub struct DataMap<I: ?Sized + 'static, O: 'static> { /* private fields */ }
A mapping of an RwData

Implementations

Source

impl<I: ?Sized, O> DataMap<I, O>

pub fn call(&self, pa: &Pass) -> O

Call this DataMap’s mapping function, returning the output

pub fn map<O2>(self, f: impl FnMut(O) -> O2 + 'static) -> DataMap<I, O2>

Maps the value within, works just like RwData::map

pub fn has_changed(&self) -> bool

Wether someone else called write or write_as since the last read or write

Do note that this DOES NOT mean that the value inside has actually been changed, it just means a mutable reference was acquired after the last call to has_changed.

Some types like Text, and traits like Widget offer needs_update methods, you should try to determine what parts to look for changes.

Generally though, you can use this method to gauge that.

pub fn checker(&self) -> impl Fn() -> bool + Send + Sync + 'static

A function that checks if the data has been updated

Do note that this function will check for the specific RwData that was used in its creation, so if you call read on that specific RwData for example, this function will start returning false.