Form

Struct Form 

pub struct Form {
    pub style: ContentStyle,
    /* private fields */
}
A style for text.

Fields

style: ContentStyle

The actual style that is applied

Implementations

Source

impl Form

pub const fn bold(self) -> Form

New Form with the bold attribute.

pub const fn dim(self) -> Form

New Form with the dim attribute.

pub const fn italic(self) -> Form

New Form with the italic attribute.

pub const fn underlined(self) -> Form

New Form with the underlined attribute.

pub const fn double_underlined(self) -> Form

New Form with the double_underlined attribute.

pub const fn undercurled(self) -> Form

New Form with the undercurled attribute.

pub const fn underdashed(self) -> Form

New Form with the underdashed attribute.

pub const fn reverse(self) -> Form

New Form with the reverse attribute.

pub const fn crossed_out(self) -> Form

New Form with the crossed_out attribute.

pub const fn black(self) -> Form

New Form with a black foreground.

pub const fn on_black(self) -> Form

New Form with a black background.

pub const fn underline_black(self) -> Form

New Form with a black underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn dark_grey(self) -> Form

New Form with a dark_grey foreground.

pub const fn on_dark_grey(self) -> Form

New Form with a dark_grey background.

pub const fn underline_dark_grey(self) -> Form

New Form with a dark_grey underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn red(self) -> Form

New Form with a red foreground.

pub const fn on_red(self) -> Form

New Form with a red background.

pub const fn underline_red(self) -> Form

New Form with a red underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn dark_red(self) -> Form

New Form with a dark_red foreground.

pub const fn on_dark_red(self) -> Form

New Form with a dark_red background.

pub const fn underline_dark_red(self) -> Form

New Form with a dark_red underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn green(self) -> Form

New Form with a green foreground.

pub const fn on_green(self) -> Form

New Form with a green background.

pub const fn underline_green(self) -> Form

New Form with a green underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn dark_green(self) -> Form

New Form with a dark_green foreground.

pub const fn on_dark_green(self) -> Form

New Form with a dark_green background.

pub const fn underline_dark_green(self) -> Form

New Form with a dark_green underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn yellow(self) -> Form

New Form with a yellow foreground.

pub const fn on_yellow(self) -> Form

New Form with a yellow background.

pub const fn underline_yellow(self) -> Form

New Form with a yellow underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn dark_yellow(self) -> Form

New Form with a dark_yellow foreground.

pub const fn on_dark_yellow(self) -> Form

New Form with a dark_yellow background.

pub const fn underline_dark_yellow(self) -> Form

New Form with a dark_yellow underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn blue(self) -> Form

New Form with a blue foreground.

pub const fn on_blue(self) -> Form

New Form with a blue background.

pub const fn underline_blue(self) -> Form

New Form with a blue underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn dark_blue(self) -> Form

New Form with a dark_blue foreground.

pub const fn on_dark_blue(self) -> Form

New Form with a dark_blue background.

pub const fn underline_dark_blue(self) -> Form

New Form with a dark_blue underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn magenta(self) -> Form

New Form with a magenta foreground.

pub const fn on_magenta(self) -> Form

New Form with a magenta background.

pub const fn underline_magenta(self) -> Form

New Form with a magenta underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn dark_magenta(self) -> Form

New Form with a dark_magenta foreground.

pub const fn on_dark_magenta(self) -> Form

New Form with a dark_magenta background.

pub const fn underline_dark_magenta(self) -> Form

New Form with a dark_magenta underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn cyan(self) -> Form

New Form with a cyan foreground.

pub const fn on_cyan(self) -> Form

New Form with a cyan background.

pub const fn underline_cyan(self) -> Form

New Form with a cyan underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn dark_cyan(self) -> Form

New Form with a dark_cyan foreground.

pub const fn on_dark_cyan(self) -> Form

New Form with a dark_cyan background.

pub const fn underline_dark_cyan(self) -> Form

New Form with a dark_cyan underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn white(self) -> Form

New Form with a white foreground.

pub const fn on_white(self) -> Form

New Form with a white background.

pub const fn underline_white(self) -> Form

New Form with a white underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

pub const fn grey(self) -> Form

New Form with a grey foreground.

pub const fn on_grey(self) -> Form

New Form with a grey background.

pub const fn underline_grey(self) -> Form

New Form with a grey underlining.

Do note that this feature may not be supported in all Uis, for example, various terminals don’t support this feature, since it is a part of the kitty protocol, and hasn’t been universally accepted yet.

Ui: crate::ui::traits::RawUi

Source

impl Form

pub const fn new() -> Form

Returns a new Form with a default style.

pub fn of(form_name: impl AsRef<str>) -> Form

A Form value, from the name of the form.

pub fn mimic(form_name: impl AsRef<str>) -> Form

A Form that mimics another.

This is useful if you want Forms to automatically change if the mimicked one does.

Normally, this is done automatically. For example, if you define a Form “foo.bar.baz” through form::id_of!, or within the txt! macro, then that Form will be set to “mimic” “foo.bar”. That is, if “foo.bar” changes, so will “foo.bar.baz”.

This function lets you manually do that.

pub const fn reset(self) -> Form

Sets the Reset attribute.

In Duat, the Reset attribute should remove only other Attributes, not any of the colors in use.

pub const fn with(self, color: &str) -> Form

Sets the color of the foreground.

This function accepts two color formats:

  • A hexcode, like "#abcdef", capitalization is ignored;
  • Three hsl values, like "hsl {hue} {sat} {lit}", where {hue}, {sat} and {lit} can either be a number from 0..255, or a percentage, followed by '%', e.g. "hsl 234 50% 42".

If this Form was created via Form::mimic, then the other attributes will change as the mimicked color does, but the foreground won’t.

pub const fn on(self, color: &str) -> Form

New Form with a colored background.

This function accepts two color formats:

  • A hexcode, like "#abcdef", capitalization is ignored;
  • Three hsl values, like "hsl {hue} {sat} {lit}", where {hue}, {sat} and {lit} can either be a number from 0..255, or a percentage, followed by '%', e.g. "hsl 234 50% 42".

If this Form was created via Form::mimic, then the other attributes will change as the mimicked color does, but the background won’t.

pub fn underline(self, color: &str) -> Form

New Form with a colored underline..

Note that this doesn’t actually make the underline show up, it merely colors one that is set via a command like Form::underlined.

This function accepts two color formats:

  • A hexcode, like "#abcdef", capitalization is ignored;
  • Three hsl values, like "hsl {hue} {sat} {lit}", where {hue}, {sat} and {lit} can either be a number from 0..255, or a percentage, followed by '%', e.g. "hsl 234 50% 42".

If this Form was created via Form::mimic, then the other attributes will change as the mimicked color does, but the underline color won’t.