BufferUnloaded

Struct BufferUnloaded 

pub struct BufferUnloaded(/* private fields */);
Hookable: Triggers before unloading a Buffer.

Arguments

This will happen before reloading Duat, on every Buffer that is open at that point.

If you want to handle the closure of buffers, see the hook for BufferClosed.