KeySent

Struct KeySent 

pub struct KeySent(/* private fields */);
Hookable: Triggers whenever a key is sent.

KeyEvents are “sent” when you type unmapped keys or with the keys that were mapped, this is in contrast with KeyTyped, which triggers when you type or when calling mode::type_keys. For example, if jk is mapped to <Esc>, KeyTyped will trigger once for j and once for k, while KeySent will trigger once for <Esc>.

Arguments

  • The sent key.