Binding

Enum Binding 

pub enum Binding {
    CharRange(Bound<char>, Bound<char>, KeyMod),
    FnRange(Bound<u8>, Bound<u8>, KeyMod),
    AnyModifier(KeyMod),
    AnyMedia(KeyMod),
    Any(Option<KeyMod>),
    Event(KeyCode, KeyMod),
}
Possible ways to map keys

This struct serves the purpose of allowing the use of pattern-like syntax in order to match keys in the bindings! macro, while still creating a finitely known list of keys, which can then be used for documentation.

Variants



CharRange(Bound<char>, Bound<char>, KeyMod)

A range of KeyEvents with KeyCode::Char, like KeyCode::Char('0'..='9')



FnRange(Bound<u8>, Bound<u8>, KeyMod)

A range of KeyEvents with KeyCode::F, like KeyCode::F(1..=3)



AnyModifier(KeyMod)

Any modifier key, like ModifierKeyCode::LeftShift

Unlikely to be bound



AnyMedia(KeyMod)

Any media key, like MediaKeyCode::MuteVolume



Any(Option<KeyMod>)

Any KeyCode, might match anything, given the optional KeyMod



Event(KeyCode, KeyMod)

A specific KeyCode/KeyMod combo

Implementations

Source

impl Binding

pub fn new(code: KeyCode, modif: KeyMod) -> Self

Returns a new concrete Binding

pub fn anything() -> Self

Returns a Binding that could match anything

pub fn as_text(&self) -> Text

The default Text formatting for a Binding

This function makes use of the key.char, key.mod, key.special, key.range and key.any Forms.

pub fn modifier(&self) -> Option<KeyMod>

The KeyMod for this Binding

Can be None in case the Binding accepts any KeyEvent whatsoever.

pub fn as_key_event(&self) -> Option<KeyEvent>

A KeyEvent, with assumptions about less used options

Only returns Some if this is Binding::Event with a concrete KeyCode and KeyMod.

pub fn matches(&self, key_event: KeyEvent) -> bool

Wether a KeyEvent would be matched by this Binding