TwoPointsPlace

Enum TwoPointsPlace 

pub enum TwoPointsPlace {
    Within(TwoPoints),
    AheadOf(TwoPoints),
}
Where exactly did the TwoPoints for a given Coord match.

It can be either an exact match, that is, the mouse was in the position of the TwoPoints, or it can be on the same line as the TwoPoints at the end of the line.

Variants



Within(TwoPoints)

The mouse was on top of the character that matched.



AheadOf(TwoPoints)

The mouse was on the same line as the character.

Implementations

Source

impl TwoPointsPlace

pub fn points(&self) -> TwoPoints

The TwoPoints that were interacted with.

pub fn as_within(&self) -> Option<TwoPoints>

Returns Some if the TwoPoints were within the Text.

pub fn as_ahead(&self) -> Option<TwoPoints>

Returns Some if the TwoPoints were ahead of the Text.