Bindings

Struct Bindings 

pub struct Bindings {
    pub title: Option<Text>,
    pub list: Vec<(Vec<Binding>, Text, Option<Bindings>)>,
}
A list of key bindings available in a given Mode

This list is used for two purposes:

  • Provide information about which keys are available in any given Mode.
  • Tell the user when they typed in a unavailable binding.
  • Warn them when they map or alias to a unavailable binding.

You should always create this struct via

Fields

title: Option<Text>

An optional title for this Bindings

This should be used to more accurately describe an overall “theme” for all keybindings listed.

list: Vec<(Vec<Binding>, Text, Option<Bindings>)>

Descriptions for each of the key bindings

The bindings of the first element are na alternation, not a sequence.

Direct implementation is not recommended, use the bindings! macro instead.

Implementations

Source

impl Bindings

pub fn matches_sequence(&self, seq: &[KeyEvent]) -> bool

Wether these MappedBindings accepts the sequence of KeyEvents

pub fn sequence_has_followup(&self, seq: &[KeyEvent]) -> bool

Wether the given sequence of KeyEvents has a followup in these MappedBindings

pub fn bindings_for(&self, seq: &[KeyEvent]) -> Option<&Bindings>

Which Bindings are available, given the passed sequence

pub fn description_for<'a>(&'a self, seq: &[KeyEvent]) -> Option<&'a Text>

The description for a particular sequence of bound keys

pub fn description_for_mut<'a>( &'a mut self, seq: &[KeyEvent], ) -> Option<&'a mut Text>

The description for a particular sequence of bound keys