RemapBuilder

Struct RemapBuilder 

pub struct RemapBuilder { /* private fields */ }
A mapping constructor, used by the map and alias commands

This builder’s purpose is pretty much just to let you document your mappings. This can be useful especially for Plugin writers.

The mapping is done once the RemapBuilder is dropped, so assigning it to a variable is not recommended

Implementations

Source

impl RemapBuilder

pub fn doc<T: Into<Text>>(self, doc: T)

Adds documentation for the mapped sequence

This documentation will be shown alongside the rest of the Bindings for the Mode. If this function is not called, then the sequence will be shown by itself.