Watcher

Struct Watcher 

pub struct Watcher(/* private fields */);
A Path watcher.

If this struct is dropped, the Paths it was watching will no longer be watched by it.

Implementations

Source

impl Watcher

pub fn new( callback: impl FnMut(Result<Event>, FromDuat) + Send + 'static, ) -> Result<Self>

Spawn a new Watcher, with a callback function

You can add paths to watch through Watcher::watch and Watcher::watch_recursive.

pub fn watch(&self, path: &Path) -> Result<()>

Watch a Path non-recursively.

pub fn watch_recursive(&self, path: &Path) -> Result<()>

Watch a Path recursively.

pub fn unwatch(&self, path: &Path) -> Result<()>

Stop watching a Path.