Module process

Module process 

Utilities for spawning processes that should outlive the config.

Structs

InterruptReader
An interruptable, buffered Reader.
PersistentChild
Behaves nearly identically to a regular Child, except the stdin pipe is wrapped in a BufWriter and the stdout and stderr pipes are wrapped in an /// InterruptReader.

Functions

get
Get a Child process that might have been spawned in a previous reload cycle.
get_or_spawn
A combination of the spawn ang get commands, letting you “lazyly” spawn processes.
is_interrupt
Wether the std::io::Error in question is an interruption triggered right before ConfigUnloaded.
spawn
Spawn a new PersistentChild, which can be reused in future config reloads.
store
Store a PersistentChild process for retrieval on a future reload.