Plugins

Struct Plugins 

pub struct Plugins(/* private fields */);
A struct for Plugins to declare dependencies on other Plugins.

Implementations

Source

impl Plugins

pub fn require<P: Plugin + Default>(&self)

Require that a Plugin be added.

This plugin may have already been added, or it might be added by this call.

For built-in Plugins, if they are required by some Plugin, then they will be added before that Plugin is added. Otherwise, they will be added at the end of the setup function.