pub enum BuilderPart<'a, D: Display = String, _T = ()> {
Text(&'a Text),
Builder(&'a Builder),
ToString(&'a D),
Path(&'a Path),
PathKind(Text),
Form(FormTag),
Spacer(PhantomData<_T>),
Ghost(&'a Ghost),
SwapChar(SwapChar),
}Expand description
A part to be pushed to a Builder by a macro
Variants
Text(&'a Text)
Text to be pushed
Note
Every Text struct has a \n attached at the end,
but when pushing it to a Builder, said \n is
automatically removed. If you want to keep a \n at the
end, push an additional one.
Builder(&'a Builder)
A Text Builder
Much like the Text, normally, the Builder finishes
with a \n, but when pushed to another Builder, that \n
is removed as well.
ToString(&'a D)
An impl Display type
Path(&'a Path)
An Path reference
PathKind(Text)
A PathKind
Form(FormTag)
A FormId
Spacer(PhantomData<_T>)
A spacer for more advanced alignment
Ghost(&'a Ghost)
Ghost Text that is separate from the real thing
SwapChar(SwapChar)
A SwapChar tag