Inlay

Struct Inlay 

pub struct Inlay { /* private fields */ }
Builder part and Tag: Places ghost Text within real Text.

This is useful when, for example, creating command line prompts, since the text is non interactable.

Implementations

Source

impl Inlay

pub fn new(value: impl Into<Text>) -> Self

Returns a new inlay type Inlay, which can be inserted on Text.

This ghost Text will be placed as if it were regular text, taking up space on screen, shifting the real text around to accomodate itself. One of the most prominent uses of it is in the prompt text of the PromptLine.

If you want ghost Text that goes over the real Text, check out Overlay.

pub fn text(&self) -> &Text

The Text of this Inlay