Point

Struct Point 

pub struct Point { /* private fields */ }
A position in Text.

This position is composed of a byte index, a character index, and a line index, all from the start of the Text.

Implementations

Source

impl Point

pub const fn new() -> Self

Returns a new Point, at the first byte.

pub const fn from_raw(b: usize, c: usize, l: usize) -> Self

A Point from raw indices.

pub const fn to_two_points_before(self) -> TwoPoints

Returns a new TwoPoints that includes the Ghosts in the same byte, if there is one.

pub const fn to_two_points_after(self) -> TwoPoints

Returns a new TwoPoints that skips the Ghosts in the same byte, if there is one.

pub fn end_point_of(str: impl AsRef<str>) -> Self

The len Point of a &str.

This is the equivalent of Strs::end_point, but for types other than Text

pub const fn byte(&self) -> usize

Returns the byte (relative to the beginning of the buffer) of self. Indexed at 0.

You can use byte indices to index the Text, Strs, or Tags with the Strs::point_at_byte function.

pub const fn char(&self) -> usize

Returns the char index (relative to the beginning of the buffer). Indexed at 0.

pub const fn line(&self) -> usize

Returns the line. Indexed at 0.

pub fn checked_sub(self, rhs: Point) -> Option<Point>

Checked Point subtraction.