Spacer

Struct Spacer 

pub struct Spacer;
Tag: A spacer for more advanced alkignment.

When printing this screen line (one row on screen, i.e. until it wraps), Instead of following the current alignment, will put spacing between the next and previous characters. The length of the space will be roughly equal to the available space on this line divided by the number of Spacers on it.

Example

Let’s say that this is the line being printed:

txt!("This is my line,please,pretend it has tags");

If we were to print it with {Spacer} like this:

txt!("This is my line,{Spacer}please,{Spacer}pretend it has tags");

In a region with a width of 50, it would come out like:

This is my line,    please,    pretend it has tags