pub struct TextParts<'t> {
pub strs: &'t Strs,
pub tags: Tags<'t>,
pub selections: &'t Selections,
}Expand description
The Parts that make up a Text.
Fields
strs: &'t Strsselections: &'t SelectionsThe Selections of the Text.
For most Widgets, there should be no Selection, since
they are just visual.
Implementations
Sourceimpl<'t> TextParts<'t>
impl<'t> TextParts<'t>
Sourcepub fn version(&self) -> TextVersion
pub fn version(&self) -> TextVersion
A struct representing how many changes took place since the
creation of this Text
This struct tracks all Changes and Tag
additions/removals, giving you information about wether this
Text has changed, when comparing this to previous
TextVersions of the same Text.
This does also include things like undoing and redoing. This is done to keep track of all changes that took place, even to previously extant states of the text.