TextPlace

Struct TextPlace 

pub struct TextPlace<'t> {
    pub real: Point,
    pub ghost: Option<Point>,
    pub part: TextPart<'t>,
}
An element of a Text.

This struct is comprised of three parts:

  • A real Point, representing a position on the real Text;
  • A ghost Point, which is a position in a Ghost, None if not in a Ghost;
  • A [TextPart], which will either be a char or a Tag;

Fields

real: Point

The real Point.

ghost: Option<Point>

The Point in a Ghost.

If there are multiple Ghosts in the same character, this Point will point to a sum of the previous Text’s lengths plus the position on this specific Ghost, so every Point should point to a specific position in a char.

part: TextPart<'t>

A [TextPart], which will either be a char or a Tag;

Implementations

Source

impl<'t> TextPlace<'t>

pub const fn is_real(&self) -> bool

Whether this TextPlace is in a Ghost.

pub const fn as_real_char(self) -> Option<(Point, char)>

Returns the real position, if not on a Ghost.

pub const fn byte(&self) -> usize

The real byte.

pub const fn char(&self) -> usize

The real char.

pub const fn line(&self) -> usize

The real line.

pub const fn points(&self) -> TwoPoints

The real and ghost Points, can be used as TwoPoints.