pub struct Columns {
pub line: usize,
pub wrapped: usize,
pub len: usize,
}Expand description
Information about the horizontal place of a TwoPoints
Fields
line: usizeThe distance from the last \n character (or start).
wrapped: usizeThe distance from the leftmost edge of the area.
len: usizeHow much horizontal space the character in this position is occupying.