Ui

Struct Ui 

pub struct Ui { /* private fields */ }
A type erased Ui

Implementations

Source

impl Ui

pub fn new_root(&self, file_path: Option<&Path>) -> RwArea

Initiates and returns a new “master” Area

This Area must not have any parents, and must be placed on a new window, that is, a plain region with nothing in it.

pub fn new_dyn_spawned( &self, file_path: Option<&Path>, spawn_id: SpawnId, specs: DynSpawnSpecs, win: usize, ) -> RwArea

Initiates and returns a new “dynamic spawned” RwArea

This is one of three ways of spawning floating Widgets. Another is with RawArea::spawn, in which a Widget will be bolted on the edges of another. Another one is through RawUi::new_static_spawned.

pub fn new_static_spawned( &self, file_path: Option<&Path>, spawn_id: SpawnId, specs: StaticSpawnSpecs, win: usize, ) -> RwArea

Initiates and returns a new “static spawned” RawArea

This is one of three ways of spawning floating Widgets. Another is with RawArea::spawn, in which a Widget will be bolted on the edges of another. Another one is through RawUi::new_dyn_spawned.

pub fn switch_window(&self, win: usize)

Switches the currently active window

This will only happen to with window indices that are actual windows. If at some point, a window index comes up that is not actually a window, that’s a bug.

pub fn flush_layout(&self)

Flush the layout

When this function is called, it means that Duat has finished adding or removing widgets, so the ui should calculate the layout.

pub fn print(&self)

Prints the layout

Since printing runs all on the same thread, it is most efficient to call a printing function after all the widgets are done updating, I think.

pub fn unload(&self)

Unloads the RawUi

Unlike RawUi::close, this will happen both when Duat reloads the configuratio and when it closes the app.

These will happen inside of the dynamically loaded config crate.

pub fn remove_window(&self, win: usize)

Removes a window from the RawUi

This should keep the current active window consistent. That is, if the current window was ahead of the deleted one, it should be shifted back, so that the same window is still displayed.

pub fn size(&self) -> Coord

The bottom right Coord on the screen

Since the top left coord is Coord { x: 0.0, y: 0.0 }, this is also the size of the window.