Windows

Struct Windows 

pub struct Windows { /* private fields */ }
A list of all Windows in Duat.

Implementations

Source

impl Windows

pub fn jump_buffers_by(&self, pa: &mut Pass, jumps: i32)

Jumps around in the buffer history.

This will jump forwards if number is positive, backwards otherwise.

pub fn last_switched_buffer(&self, pa: &mut Pass) -> Result<Handle, Text>

Jumps to the last buffer.

Calling this repeatedly will switch you through the Buffer switch history.

pub fn size(&self) -> Coord

The bottom right Coord on the screen.

Since the top left coord is Coord { x: 0.0, y: 0.0 }, this is also the size of the window.

pub fn len(&self, pa: &Pass) -> usize

The number of open Windows.

Should never be 0, as that is not a valid state of affairs.

pub fn get<'a>(&'a self, pa: &'a Pass, win: usize) -> Option<&'a Window>

get’s the winth Window.

pub fn iter<'a>(&'a self, pa: &'a Pass) -> Iter<'a, Window>

Iterates through every Window.

pub fn handles<'a>( &'a self, pa: &'a Pass, ) -> impl Iterator<Item = Handle<dyn Widget>> + 'a

Returns an Iterator over the Handles of Duat.

pub fn handles_of<W: Widget>(&self, pa: &Pass) -> Vec<Handle<W>>

Returns an Iterator over the Handles of Duat.

pub fn buffers(&self, pa: &Pass) -> Vec<Handle>

Iterates over all Handle<Buffer>s in Duat.

pub fn current_window(&self, pa: &Pass) -> usize

The index of the currently active Window.