Change

Struct Change 

pub struct Change<'h, S = &'h str> { /* private fields */ }
A change in a buffer, with a start, taken text, and added text

If you acquired this Change from a BufferTracker::parts call, you need not worry about adding it to the ranges that need to be updated, as that has already been done.

Implementations

Source

impl Change<'static, String>

pub fn new(edit: impl ToString, range: Range<Point>, text: &Text) -> Self

Returns a new Change.

pub fn as_ref(&self) -> Change<'_, &str>

Returns a copyable Change

pub fn try_merge(&mut self, older: Self)

In this function, it is assumed that self happened after newer

If the merger fails, the older Change will be returned;

Source

impl<'h> Change<'h>

pub fn to_string_change(&self) -> Change<'static, String>

Creates a Change<String> from a Change<&str>

pub fn str_insert(added_str: &'h str, start: Point) -> Self

Returns a new copyable Change from an insertion.

Source

impl<'s, S: Borrow<str>> Change<'s, S>

pub fn reverse(self) -> Self

Returns a reversed version of this Change

pub fn line_range(&self, strs: &Strs) -> Range<Point>

Gets a Range<Point>, from the start to the end of the affected lines

For example, if you make an edit that transforms lines 1..=3 to lines 1..=5, this function will return a Range that starts at the beginning of line 1, and ends at the end of line 5.

Note

This end of this range will come after the last \n, which means that, in that example, said point would have a Point::line value equal to 6, not 5, since it represents both the end of line 5, and the beginning of line 6.

pub fn start(&self) -> Point

The Point at the start of the change

pub fn taken_end(&self) -> Point

Returns the end of the Change, before it was applied

pub fn added_end(&self) -> Point

Returns the end of the Change, after it was applied

pub fn taken_range(&self) -> Range<Point>

Returns the taken Range

pub fn added_range(&self) -> Range<Point>

Returns the added Range

pub fn added_str(&self) -> &str

The text that was taken on this Change

pub fn taken_str(&self) -> &str

The text that was added by this Change

pub fn shift(&self) -> [i32; 3]

The total shift caused by this Change