pub struct Moment { /* private fields */ }Expand description
A moment in history, which may contain changes, or may just contain selections.
It also contains information about how to print the buffer, so that going back in time is less jarring.
Implementations