pub enum WidgetRelation {
Main,
Pushed,
Spawned,
}Expand description
What relation this Widget has to its parent.
Variants
Main
The main widget of the cluster, most commonly a Buffer.
Pushed
A Widget that was pushed around the main Widget, e.g.
LineNumbers.
Spawned
A Widget that was spawned on the Widget, e.g. completion.
lists