pub fn queue(f: impl FnOnce(&mut Pass) + Send + 'static)Expand description
Queues a function to be done on the main thread with a
Pass.
You can use this whenever you don’t have access to a Pass,
in order to execute an action on the main thread, gaining
access to Duat’s global state within that function.
Note that, since this can be called from any thread, it needs
to be Send and 'static.