pub struct BufferPrinted(/* private fields */);Expand description
Hookable: Triggers after a Buffer is printed.
The primary purpose of this Widget is to do cleanup on temporary
changes made during a BufferUpdated triggering.
One example of this is with the default BufferOpts, which allow
you to hightlight the current cursor line. Since this makes use of
disruptive Tags, it is best to do this only during the printing
process, then get rid of said tags.
Warning
Any changes done to the Buffer or Area from this hook will
not be checked in order for a reprint. This is to avoid
repeatedly printing over and over again.