pub struct BufferUnloaded(/* private fields */);Expand description
Hookable: Triggers before unloading a Buffer.
Arguments
- The
Buffer’sHandle.
This will happen before reloading Duat, on every Buffer that is
open at that point.
If you want to handle the closure of buffers, see the hook for
BufferClosed.