pub enum TwoPointsPlace {
Within(TwoPoints),
AheadOf(TwoPoints),
}Expand description
Variants
Within(TwoPoints)
The mouse was on top of the character that matched.
AheadOf(TwoPoints)
The mouse was on the same line as the character.
Implementations