pub struct MouseEvent<'h, W: ?Sized = dyn Widget> {
pub handle: &'h Handle<W>,
pub points: Option<TwoPointsPlace>,
pub coord: Coord,
pub kind: MouseEventKind,
pub modifiers: KeyMod,
}Expand description
A mouse event, representing a click, drag, hover, etc.
Fields
handle: &'h Handle<W>The Handle where the event took place.
points: Option<TwoPointsPlace>The position on the Text where the mouse was.
coord: CoordThee coordinate on screen where the mouse was.
kind: MouseEventKindWhat the mouse did.
modifiers: KeyModModifiers that were pressed during this mouse event.