Utilities for spawning processes that should outlive the config.
Structs
- Interrupt
Reader - An interruptable, buffered
Reader. - Persistent
Child - Behaves nearly identically to a regular
Child, except thestdinpipe is wrapped in aBufWriterand thestdoutandstderrpipes are wrapped in an ///InterruptReader.
Functions
- get
- Get a
Childprocess that might have been spawned in a previous reload cycle. - get_
or_ spawn - A combination of the
spawnanggetcommands, letting you “lazyly” spawn processes. - is_
interrupt - Wether the
std::io::Errorin question is an interruption triggered right beforeConfigUnloaded. - spawn
- Spawn a new
PersistentChild, which can be reused in future config reloads. - store
- Store a
PersistentChildprocess for retrieval on a future reload.