pub struct Inlay { /* private fields */ }Expand description
Implementations
Sourceimpl Inlay
impl Inlay
Sourcepub fn new(value: impl Into<Text>) -> Self
pub fn new(value: impl Into<Text>) -> Self
Returns a new inlay type Inlay, which can be inserted on
Text.
This ghost Text will be placed as if it were regular text,
taking up space on screen, shifting the real text around to
accomodate itself. One of the most prominent uses of it is in
the prompt text of the PromptLine.
If you want ghost Text that goes over the real Text,
check out Overlay.