pub struct Mask(pub &'static str);Expand description
Tag: A mask that maps Forms based on a suffix.
This works like this: If the form named form.middle was applied
to a region, and said region had the mask1 mask applied to it
(via this struct), then instead of applying the form.middle
form, duat would apply form.middle.mask1.
Unless form.middle.mask1 is explicitely set, then it is
automatically defined as the same thing as form.middle.
Tuple Fields
0: &'static strImplementations