Overlay

Struct Overlay 

pub struct Overlay { /* private fields */ }
Builder part and Tag: Places ghost Text within real Text.

This is useful when, for example, creating command line prompts, since the text is non interactable.

Implementations

Source

impl Overlay

pub fn new(value: impl Into<Text>) -> Self

Returns a new “overlay” type Inlay, which can be inserted on Text.

This ghost Text will cover up the real text, while still letting the Form tags of the real text affect it. One of the most prominent uses of it is in the indent guides.

If you want ghost Text that goes over the real Text, check out Overlay.