pub struct Point { /* private fields */ }Expand description
A position in Text.
This position is composed of a byte index, a character index, and
a line index, all from the start of the Text.
Implementations
Sourceimpl Point
impl Point
Sourcepub const fn to_two_points_before(self) -> TwoPoints
pub const fn to_two_points_before(self) -> TwoPoints
Sourcepub const fn to_two_points_after(self) -> TwoPoints
pub const fn to_two_points_after(self) -> TwoPoints
Sourcepub fn end_point_of(str: impl AsRef<str>) -> Self
pub fn end_point_of(str: impl AsRef<str>) -> Self
This is the equivalent of Strs::end_point, but for types
other than Text
Sourcepub const fn byte(&self) -> usize
pub const fn byte(&self) -> usize
Returns the byte (relative to the beginning of the buffer) of self. Indexed at 0.
You can use byte indices to index the Text, Strs, or
Tags with the Strs::point_at_byte function.