TextParts

Struct TextParts 

pub struct TextParts<'t> {
    pub strs: &'t Strs,
    pub tags: Tags<'t>,
    pub selections: &'t Selections,
}
The Parts that make up a Text.

Fields

strs: &'t Strs

The Strs of the whole Text.

tags: Tags<'t>

The Tags of the Text.

This, unlike the previous field, allows mutation in the form of adding and removing Tags.

selections: &'t Selections

The Selections of the Text.

For most Widgets, there should be no Selection, since they are just visual.

Implementations

Source

impl<'t> TextParts<'t>

pub fn version(&self) -> TextVersion

A struct representing how many changes took place since the creation of this Text

This struct tracks all Changes and Tag additions/removals, giving you information about wether this Text has changed, when comparing this to previous TextVersions of the same Text.

This does also include things like undoing and redoing. This is done to keep track of all changes that took place, even to previously extant states of the text.