pub struct TextPlace<'t> {
pub real: Point,
pub ghost: Option<Point>,
pub part: TextPart<'t>,
}Expand description
Fields
real: PointThe real Point.
ghost: Option<Point>If there are multiple Ghosts in the same character, this
Point will point to a sum of the previous Text’s
lengths plus the position on this specific Ghost, so
every Point should point to a specific position in a char.
part: TextPart<'t>A [TextPart], which will either be a char or a Tag;
Implementations