pub struct Windows { /* private fields */ }Expand description
A list of all Windows in Duat.
Implementations
Sourceimpl Windows
impl Windows
Sourcepub fn jump_buffers_by(&self, pa: &mut Pass, jumps: i32)
pub fn jump_buffers_by(&self, pa: &mut Pass, jumps: i32)
Jumps around in the buffer history.
This will jump forwards if number is positive, backwards
otherwise.
Sourcepub fn last_switched_buffer(&self, pa: &mut Pass) -> Result<Handle, Text>
pub fn last_switched_buffer(&self, pa: &mut Pass) -> Result<Handle, Text>
Jumps to the last buffer.
Calling this repeatedly will switch you through the Buffer
switch history.
Sourcepub fn size(&self) -> Coord
pub fn size(&self) -> Coord
The bottom right Coord on the screen.
Since the top left coord is Coord { x: 0.0, y: 0.0 }, this
is also the size of the window.
Sourcepub fn len(&self, pa: &Pass) -> usize
pub fn len(&self, pa: &Pass) -> usize
The number of open Windows.
Should never be 0, as that is not a valid state of affairs.
Sourcepub fn get<'a>(&'a self, pa: &'a Pass, win: usize) -> Option<&'a Window>
pub fn get<'a>(&'a self, pa: &'a Pass, win: usize) -> Option<&'a Window>
get’s the winth Window.
Sourcepub fn handles<'a>(
&'a self,
pa: &'a Pass,
) -> impl Iterator<Item = Handle<dyn Widget>> + 'a
pub fn handles<'a>( &'a self, pa: &'a Pass, ) -> impl Iterator<Item = Handle<dyn Widget>> + 'a
Sourcepub fn current_window(&self, pa: &Pass) -> usize
pub fn current_window(&self, pa: &Pass) -> usize
The index of the currently active Window.